@@ -375,7 +375,7 @@ func (c *Upgrader) UpdateGrub() (stateType, error) {
 
 func (c *Upgrader) EnableBoot(version string) (stateType, error) {
 	exitCode := _STATE_TY_SUCCESS
-	err := c.Snapshot(version)
+	err := c.repoSnapShotSubDir(c.conf.RepoList[0], "/boot", version)
 	if err != nil {
 		exitCode = _STATE_TY_FAILED_NO_REPO
 		return exitCode, err
@@ -670,16 +670,20 @@ failure:
 func (c *Upgrader) repoCommit(repoConf *config.RepoConfig, newVersion, subject string,
 	useSysData bool, evHandler func(op, state int32, target, desc string)) error {
 	handler := c.repoSet[repoConf.Repo]
-	dataDir := filepath.Join(c.rootMP, c.conf.CacheDir, c.conf.Distribution)
+	var dataDir, usrDir string
 	defer func() {
 		// remove tmp dir
 		_ = os.RemoveAll(filepath.Join(c.rootMP, c.conf.CacheDir))
 	}()
 	if useSysData {
 		c.SendingSignal(evHandler, _OP_TY_COMMIT_PREPARE_DATA, _STATE_TY_RUNING, newVersion, "")
-		// judging that the space for creating temporary files is sufficient
-		usrDir := filepath.Join(c.rootMP, "/usr")
-
+		if chroot.IsEnv() {
+			usrDir = "/usr"
+		} else {
+			usrDir = c.getMostSpaceDir(c.rootMP, repoConf.SubscribeList)
+		}
+		c.conf.SetCacheDir(filepath.Join(usrDir, ".osrepo-cache"))
+		logger.Infof("to reset the temporary directory %s", c.conf.CacheDir)
 		// need to delete the repo to take up space, if a repo in the subscribeList
 		var extraSize int64
 		for _, v := range repoConf.SubscribeList {
@@ -697,6 +701,7 @@ func (c *Upgrader) repoCommit(repoConf *config.RepoConfig, newVersion, subject s
 		// need handle filter dirs
 		repoConf.FilterList = append(repoConf.FilterList, c.getFilterList(repoConf.FilterList, repoConf.SubscribeList)...)
 		repoConf.FilterList = util.RemoveSameItemInSlice(repoConf.FilterList)
+		dataDir = filepath.Join(c.rootMP, c.conf.CacheDir, c.conf.Distribution)
 		err = c.copyRepoData(c.rootMP, dataDir, repoConf.SubscribeList, repoConf.FilterList)
 		if err != nil {
 			return err
@@ -758,13 +763,19 @@ func (c *Upgrader) repoSnapShot(repoConf *config.RepoConfig, version string) err
 	return handler.Snapshot(version, dataDir)
 }
 
+func (c *Upgrader) repoSnapShotSubDir(repoConf *config.RepoConfig, subDir, version string) error {
+	handler := c.repoSet[repoConf.Repo]
+	dataDir := filepath.Join(c.rootMP, repoConf.SnapshotDir, version)
+	_ = os.RemoveAll(dataDir)
+	return handler.SnapshotSub(version, subDir, dataDir)
+}
+
 func (c *Upgrader) enableSnapshotBoot(snapDir, version string) error {
-	bootDir := filepath.Join(snapDir, "boot")
+	bootDir := snapDir
 	fiList, err := ioutil.ReadDir(bootDir)
 	if err != nil {
 		return err
 	}
-
 	dstDir := filepath.Join(c.rootMP, "boot/snapshot", version)
 	localBootDir := filepath.Join(c.rootMP, "/boot")
 	err = os.MkdirAll(dstDir, 0700)
@@ -1071,6 +1082,39 @@ func (c *Upgrader) copyRepoData(rootDir, dataDir string,
 	return nil
 }
 
+func (c *Upgrader) getMostSpaceDir(rootDir string, subscribeList []string) string {
+	mp := make(map[string]int64)
+	var maxUsePart string
+	var max, total int64
+	for _, dir := range subscribeList {
+		srcDir := filepath.Join(rootDir, dir)
+		part, err := dirinfo.GetDirPartition(srcDir)
+		if err != nil {
+			continue
+		}
+		v, ok := mp[part]
+		if !ok {
+			mp[part] = dirinfo.GetDirSize(srcDir)
+		} else {
+			mp[part] += v + dirinfo.GetDirSize(srcDir)
+		}
+		if max < mp[part] {
+			max = mp[part]
+			maxUsePart = part
+		}
+	}
+	info := c.mountInfos.MatchPartition(maxUsePart)
+	free, _ := dirinfo.GetPartitionFreeSize(info.MountPoint)
+	for v := range mp {
+		total += mp[v]
+	}
+	logger.Debugf("maximum use space partition %s,", maxUsePart)
+	if int64(free) > (total - max) {
+		return info.MountPoint
+	}
+	return c.mountInfos.MaxPartition(subscribeList)
+}
+
 func (c *Upgrader) isDirSpaceEnough(mountpoint, rootDir string, subscribeList []string,
 	extraSize int64, isFilterPartiton bool) (bool, error) {
 	var needSize int64
@@ -1497,7 +1541,7 @@ func (c *Upgrader) SendSystemNotice() error {
 	grubServiceObj := sysBus.Object(atomicUpgradeDest,
 		atomicUpgradePath)
 	res, afterRun, err := records.ReadResult()
-	logger.Debugf("current self run %s, res %s", afterRun, res)
+	logger.Debugf("current self run %s, res %v", afterRun, res)
 	var ret dbus.Variant
 	dbusErr := grubServiceObj.Call("org.freedesktop.DBus.Properties.Get", 0, atomicUpgradeDest, "ActiveVersion").Store(&ret)
 	activeVersion := ret.Value().(string)
